pub struct MockTransport {
pub sent_log: Vec<Vec<u8>>,
pub recv_log: Vec<Vec<u8>>,
/* private fields */
}Expand description
Connected mock transport. All traffic is recorded for assertion.
Fields
sent_log: Vec<Vec<u8>>Every byte sequence this end has sent, in order.
recv_log: Vec<Vec<u8>>Every byte sequence this end has received, in order.
Implementations